package com.sun.media.sound;

import java.util.Arrays;
import javax.sound.sampled.AudioFormat;

public final class SoftAudioBuffer
{
    private int size;
    private float[] buffer;
    private boolean empty;
    private AudioFormat format;
    private AudioFloatConverter converter;
    private byte[] converter_buffer;
    
    public SoftAudioBuffer(int size, AudioFormat format) {
        this.empty = true;
        this.size = size;
        this.format = format;
        this.converter = AudioFloatConverter.getConverter(format);
    }
    
    public void swap(SoftAudioBuffer softAudioBuffer) {
        int size = this.size;
        float[] buffer = this.buffer;
        int empty = this.empty;
        AudioFormat format = this.format;
        AudioFloatConverter converter = this.converter;
        byte[] converter_buffer = this.converter_buffer;
        this.size = softAudioBuffer.size;
        this.buffer = softAudioBuffer.buffer;
        this.empty = softAudioBuffer.empty;
        this.format = softAudioBuffer.format;
        this.converter = softAudioBuffer.converter;
        this.converter_buffer = softAudioBuffer.converter_buffer;
        softAudioBuffer.size = size;
        softAudioBuffer.buffer = buffer;
        softAudioBuffer.empty = empty;
        softAudioBuffer.format = format;
        softAudioBuffer.converter = converter;
        softAudioBuffer.converter_buffer = converter_buffer;
    }
    
    public AudioFormat getFormat() {
        return this.format;
    }
    
    public int getSize() {
        return this.size;
    }
    
    public void clear() {
        if (!this.empty) {
            Arrays.fill(this.buffer, 0.0f);
            this.empty = true;
        }
    }
    
    public boolean isSilent() {
        return this.empty;
    }
    
    public float[] array() {
        this.empty = false;
        if (this.buffer == null) {
            this.buffer = new float[this.size];
        }
        return this.buffer;
    }
    
    public void get(byte[] array, int n) {
        int n2 = this.format.getFrameSize() / this.format.getChannels();
        int n3 = this.size * n2;
        if (this.converter_buffer == null || this.converter_buffer.length < n3) {
            this.converter_buffer = new byte[n3];
        }
        if (this.format.getChannels() == 1) {
            this.converter.toByteArray(this.array(), this.size, array);
        }
        else {
            this.converter.toByteArray(this.array(), this.size, this.converter_buffer);
            if (n >= this.format.getChannels()) {
                return;
            }
            int n4 = this.format.getChannels() * n2;
            for (int i = 0; i < n2; ++i) {
                int n5 = n * n2 + i;
                for (int j = 0; j < this.size; ++j) {
                    array[n5] = this.converter_buffer[i];
                    n5 += n4;
                    i += n2;
                }
            }
        }
    }
}
